package com.gic.plug.web.controller.goods;

import java.util.*;

import org.apache.commons.collections.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.gic.api.base.commons.ServiceResponse;
import com.gic.commons.webapi.reponse.RestResponse;
import com.gic.goods.api.dto.GoodsDomainDTO;
import com.gic.goods.api.service.GoodsDomainApiService;
import com.gic.goods.api.util.Constant;
import com.gic.plug.web.vo.goods.GoodsChannelVO;
import com.gic.plug.web.vo.goods.GoodsDomainVO;

@RestController
public class GoodsDomainController {

    private static Map<String, String> channelCodeAndName;

    private static Map<String, String> channelCodeAndScene;

    static {
        channelCodeAndName = new HashMap<>();
        channelCodeAndName.put(Constant.CHANNEL_CODE_ERP, "ERP");
        channelCodeAndName.put(Constant.CHANNEL_CODE_WEIMOB, "微盟");
        channelCodeAndName.put(Constant.CHANNEL_CODE_MALL, "GIC微商城");
        channelCodeAndScene = new HashMap<>();
        channelCodeAndScene.put(Constant.CHANNEL_CODE_ERP, "erp_goods");
        channelCodeAndScene.put(Constant.CHANNEL_CODE_WEIMOB, "weimo_goods");
        channelCodeAndScene.put(Constant.CHANNEL_CODE_MALL, "GIC微商城");
    }

    @Autowired
    private GoodsDomainApiService goodsDomainApiService;

    /**
    * @Title: getAllGoodsDomianListWith
    * @Description: 查询企业下所有的域，拼接成channelVO返回
    * @author majia
    * @return  com.gic.commons.webapi.reponse.RestResponse
    * @throws
    */
    @RequestMapping("/get-all-goods-domain-list")
    private RestResponse getAllGoodsDomianListWith() {
        ServiceResponse<List<GoodsDomainDTO>> serviceResponse = goodsDomainApiService.listAll(Constant.TEST_ENTERPRISE_ID);
        if (!serviceResponse.isSuccess()) {
            return RestResponse.failure(serviceResponse.getCode(), serviceResponse.getMessage());
        }
        List<GoodsDomainDTO> goodsDomainDTOList = serviceResponse.getResult();
        Map<String, List<GoodsDomainDTO>> map = new TreeMap<>();
        if (CollectionUtils.isEmpty(goodsDomainDTOList)) {
            return RestResponse.success(Collections.EMPTY_LIST);
        }
        for (GoodsDomainDTO goodsDomainDTO : goodsDomainDTOList) {
            if (CollectionUtils.isNotEmpty(goodsDomainDTO.getChannels())){
                for (String channelCode : goodsDomainDTO.getChannels()) {
                    map.putIfAbsent(channelCode, new ArrayList<>());
                    map.get(channelCode).add(goodsDomainDTO);
                }
            }
        }
        List<GoodsChannelVO> resultList = new ArrayList<>();
        for (Map.Entry<String, List<GoodsDomainDTO>> entry : map.entrySet()) {
            GoodsChannelVO goodsChannelVO = new GoodsChannelVO();
            goodsChannelVO.setChannelCode(entry.getKey());
            goodsChannelVO.setChannelName(channelCodeAndName.get(entry.getKey()));
            goodsChannelVO.setSceneCode(channelCodeAndScene.get(entry.getKey()));
            goodsChannelVO.setGoodsDomainList(new ArrayList<>());
            for (GoodsDomainDTO goodsDomainDTO : entry.getValue()) {
                GoodsDomainVO goodsDomainVO = new GoodsDomainVO();
                goodsDomainVO.setDomainCode(goodsDomainDTO.getCode());
                goodsDomainVO.setDomainId(goodsDomainDTO.getGoodsDomainId());
                goodsDomainVO.setDomainName(goodsDomainDTO.getName());
                goodsChannelVO.getGoodsDomainList().add(goodsDomainVO);
            }
            resultList.add(goodsChannelVO);
        }
        return RestResponse.success(resultList);
    }

}
